@@ -22,6 +22,9 @@ import warnings
 
 import click
 
+from klio_core import options as core_options
+from klio_core import utils as core_utils
+
 from klio_cli import __version__ as version
 from klio_cli import options
 from klio_cli.commands import image as image_commands
@@ -109,8 +112,8 @@ def configuration():
 # `klio image` commands
 #####
 @image.command("build", help="Build the Docker worker image.")
-@options.image_tag
-@cli_utils.with_klio_config
+@core_options.image_tag(default=None, show_default="``git-sha[dirty?]``")
+@core_utils.with_klio_config
 def build_image(klio_config, config_meta, **kwargs):
     if not kwargs.get("image_tag"):
         kwargs["image_tag"] = cli_utils.get_git_sha(config_meta.job_dir)
@@ -124,9 +127,9 @@ def build_image(klio_config, config_meta, **kwargs):
 # `klio job` commands
 #####
 @job.command("run", help="Run a klio job.")
-@options.image_tag
+@core_options.image_tag(default=None, show_default="``git-sha[dirty?]``")
 @options.runtime
-@cli_utils.with_klio_config
+@core_utils.with_klio_config
 def run_job(klio_config, config_meta, **kwargs):
     direct_runner = cli_utils.is_direct_runner(
         klio_config, kwargs.pop("direct_runner")
@@ -136,9 +139,6 @@ def run_job(klio_config, config_meta, **kwargs):
         config_meta.job_dir, kwargs.get("image_tag")
     )
     image_tag = kwargs.get("image_tag") or git_sha
-    if config_meta.config_file:
-        basename = os.path.basename(config_meta.config_file)
-        image_tag = "{}-{}".format(image_tag, basename)
 
     runtime_config = DockerRuntimeConfig(
         image_tag=image_tag,
@@ -165,8 +165,8 @@ def run_job(klio_config, config_meta, **kwargs):
         "supported."
     ),
 )
-@options.job_dir
-@options.config_file
+@core_options.job_dir
+@core_options.config_file
 @options.job_name(
     help=(
         "Name of job, if neither ``--job-dir`` nor ``--config-file`` is not "
@@ -180,7 +180,7 @@ def run_job(klio_config, config_meta, **kwargs):
         "provided."
     )
 )
-@cli_utils.with_klio_config
+@core_utils.with_klio_config
 def stop_job(klio_config, config_meta, job_name, region, gcp_project):
     if job_name and any([config_meta.job_dir, config_meta.config_file]):
         logging.error(
@@ -213,9 +213,9 @@ def stop_job(klio_config, config_meta, job_name, region, gcp_project):
         "the same name & region.\n\n**NOTE:** Draining is not supported."
     ),
 )
-@options.image_tag
+@core_options.image_tag(default=None, show_default="``git-sha[dirty?]``")
 @options.runtime
-@cli_utils.with_klio_config
+@core_utils.with_klio_config
 def deploy_job(klio_config, config_meta, **kwargs):
     direct_runner = cli_utils.is_direct_runner(
         klio_config, kwargs.pop("direct_runner")
@@ -297,7 +297,7 @@ def create_job(addl_job_opts, output, **known_kwargs):
 @job.command(
     "delete", help=("Delete GCP-related resources created by a Klio job")
 )
-@cli_utils.with_klio_config
+@core_utils.with_klio_config
 def delete_job(klio_config, config_meta):
     job_commands.delete.DeleteJob(klio_config).delete()
 
@@ -308,10 +308,10 @@ def delete_job(klio_config, config_meta):
     # set this so that pytest options can be pass-thru
     context_settings=dict(ignore_unknown_options=True),
 )
-@options.image_tag
+@core_options.image_tag(default=None, show_default="``git-sha[dirty?]``")
 @options.force_build
 @click.argument("pytest_args", nargs=-1, type=click.UNPROCESSED)
-@cli_utils.with_klio_config
+@core_utils.with_klio_config
 def test_job(
     klio_config, config_meta, force_build, image_tag, pytest_args, **kwargs
 ):
@@ -356,7 +356,7 @@ def test_job(
     ),
 )
 @options.create_resources
-@cli_utils.with_klio_config
+@core_utils.with_klio_config
 def verify_job(klio_config, config_meta, create_resources):
     job = job_commands.verify.VerifyJob(klio_config, create_resources)
     job.verify_job()
@@ -372,9 +372,9 @@ def verify_job(klio_config, config_meta, create_resources):
     ),
 )
 @options.force_build
-@options.image_tag
+@core_options.image_tag(default=None, show_default="``git-sha[dirty?]``")
 @options.list_steps
-@cli_utils.with_klio_config
+@core_utils.with_klio_config
 def audit_job(klio_config, config_meta, force_build, image_tag, list_steps):
 
     git_sha = cli_utils.get_git_sha(config_meta.job_dir, image_tag)
@@ -403,7 +403,7 @@ def audit_job(klio_config, config_meta, force_build, image_tag, list_steps):
 # `klio job config` subcommands
 #####
 def _job_config(job_dir, config_file, verb, *args, **kwargs):
-    _, config_path = cli_utils.get_config_job_dir(job_dir, config_file)
+    _, config_path = core_utils.get_config_job_dir(job_dir, config_file)
 
     effective_job_config = job_commands.configuration.EffectiveJobConfig(
         config_path
@@ -415,8 +415,8 @@ def _job_config(job_dir, config_file, verb, *args, **kwargs):
 @configuration.command(
     "show", help="Show the complete effective configuration for a Klio job.",
 )
-@options.job_dir
-@options.config_file
+@core_options.job_dir
+@core_options.config_file
 def show_job_config(job_dir, config_file):
     _job_config(job_dir, config_file, "show")
 
@@ -429,8 +429,8 @@ def show_job_config(job_dir, config_file):
         "pairs of ``SECTION.PROPERTY=VALUE`` are accepted."
     ),
 )
-@options.job_dir
-@options.config_file
+@core_options.job_dir
+@core_options.config_file
 @click.argument(
     "target_to_value",
     required=True,
@@ -444,8 +444,8 @@ def set_job_config(job_dir, config_file, target_to_value):
 @configuration.command(
     "unset", help="Unset a configuration value for a Klio job.",
 )
-@options.job_dir
-@options.config_file
+@core_options.job_dir
+@core_options.config_file
 @click.argument("section_property", required=True, metavar="SECTION.PROPERTY")
 def unset_job_config(job_dir, config_file, section_property):
     _job_config(job_dir, config_file, "unset", section_property)
@@ -454,8 +454,8 @@ def unset_job_config(job_dir, config_file, section_property):
 @configuration.command(
     "get", help="Get the value for a configuration property of a Klio job.",
 )
-@options.job_dir
-@options.config_file
+@core_options.job_dir
+@core_options.config_file
 @click.argument("section_property", required=True, metavar="SECTION.PROPERTY")
 def get_job_config(job_dir, config_file, section_property):
     _job_config(job_dir, config_file, "get", section_property)
@@ -477,8 +477,8 @@ def get_job_config(job_dir, config_file, section_property):
         "``klio-job.yaml``."
     ),
 )
-@options.job_dir(mutex=["gcs_location", "input_file"])
-@options.config_file(mutex=["gcs_location", "input_file"])
+@core_options.job_dir(mutex=["gcs_location", "input_file"])
+@core_options.config_file(mutex=["gcs_location", "input_file"])
 @options.gcs_location
 @options.since
 @options.until
@@ -494,7 +494,7 @@ def get_job_config(job_dir, config_file, section_property):
 @click.argument(
     "restrictions", nargs=-1, required=False, type=click.UNPROCESSED
 )
-@cli_utils.with_klio_config
+@core_utils.with_klio_config
 def collect_profiling_data(
     klio_config,
     config_meta,
@@ -592,12 +592,12 @@ def _profile(subcommand, klio_config, config_meta, **kwargs):
         "Klio-based transforms."
     ),
 )
-@options.image_tag
+@core_options.image_tag(default=None, show_default="``git-sha[dirty?]``")
 @options.force_build
-@options.interval
-@options.include_children
-@options.multiprocess
-@options.plot_graph
+@core_options.interval
+@core_options.include_children
+@core_options.multiprocess
+@core_options.plot_graph
 @options.input_file(
     help=(
         "File of entity IDs (separated by a new line character) with "
@@ -606,9 +606,9 @@ def _profile(subcommand, klio_config, config_meta, **kwargs):
     ),
 )
 @options.output_file(help="Output file for results. [default: stdout]")
-@options.show_logs
+@core_options.show_logs
 @click.argument("entity_ids", nargs=-1, required=False)
-@cli_utils.with_klio_config
+@core_utils.with_klio_config
 def profile_memory(klio_config, config_meta, **kwargs):
     _profile("memory", klio_config, config_meta, **kwargs)
 
@@ -621,9 +621,9 @@ def profile_memory(klio_config, config_meta, **kwargs):
         "method."
     ),
 )
-@options.maximum
-@options.per_element
-@options.image_tag
+@core_options.maximum
+@core_options.per_element(show_default=True)
+@core_options.image_tag(default=None, show_default="``git-sha[dirty?]``")
 @options.force_build
 @options.input_file(
     help=(
@@ -633,9 +633,9 @@ def profile_memory(klio_config, config_meta, **kwargs):
     ),
 )
 @options.output_file(help="Output file for results. [default: stdout]")
-@options.show_logs
+@core_options.show_logs
 @click.argument("entity_ids", nargs=-1, required=False)
-@cli_utils.with_klio_config
+@core_utils.with_klio_config
 def profile_memory_per_line(klio_config, config_meta, **kwargs):
     _profile("memory-per-line", klio_config, config_meta, **kwargs)
 
@@ -648,10 +648,10 @@ def profile_memory_per_line(klio_config, config_meta, **kwargs):
         "Klio-based transforms."
     ),
 )
-@options.image_tag
+@core_options.image_tag(default=None, show_default="``git-sha[dirty?]``")
 @options.force_build
-@options.interval
-@options.plot_graph
+@core_options.interval
+@core_options.plot_graph
 @options.input_file(
     help=(
         "File of entity IDs (separated by a new line character) with "
@@ -660,9 +660,9 @@ def profile_memory_per_line(klio_config, config_meta, **kwargs):
     ),
 )
 @options.output_file(help="Output file for results. [default: stdout]")
-@options.show_logs
+@core_options.show_logs
 @click.argument("entity_ids", nargs=-1, required=False)
-@cli_utils.with_klio_config
+@core_utils.with_klio_config
 def profile_cpu(klio_config, config_meta, **kwargs):
     _profile("cpu", klio_config, config_meta, **kwargs)
 
@@ -676,7 +676,7 @@ def profile_cpu(klio_config, config_meta, **kwargs):
         "package, not Python's ``timeit`` module."
     ),
 )
-@options.image_tag
+@core_options.image_tag(default=None, show_default="``git-sha[dirty?]``")
 @options.force_build
 @options.input_file(
     help=(
@@ -686,10 +686,10 @@ def profile_cpu(klio_config, config_meta, **kwargs):
     ),
 )
 @options.output_file(help="Output file for results. [default: stdout]")
-@options.iterations
-@options.show_logs
+@core_options.iterations
+@core_options.show_logs
 @click.argument("entity_ids", nargs=-1, required=False)
-@cli_utils.with_klio_config
+@core_utils.with_klio_config
 def profile_timeit(klio_config, config_meta, **kwargs):
     _profile("timeit", klio_config, config_meta, **kwargs)
 
@@ -704,7 +704,7 @@ def profile_timeit(klio_config, config_meta, **kwargs):
 @options.bottom_up
 @options.non_klio
 @click.argument("entity_ids", nargs=-1, required=True)
-@cli_utils.with_klio_config
+@core_utils.with_klio_config
 def publish(
     entity_ids,
     force,
